/*
 * RealWear Development Software, Source Code and Object Code.
 * (c) RealWear, Inc. All rights reserved.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Contact info@realwear.com for further information about the use of this code.
 */

package com.realwear.documentviewer.adapters;

import android.graphics.Bitmap;
import android.graphics.Color;
import android.graphics.pdf.PdfRenderer;
import android.os.ParcelFileDescriptor;
import android.util.Log;
import android.view.ViewGroup;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.RecyclerView;

import com.realwear.documentviewer.object.Bookmark;
import com.realwear.documentviewer.utils.ScreenUtils;

import java.io.File;
import java.io.IOException;
import java.util.List;

public class BookmarkAdapter extends RecyclerView.Adapter<BookmarkViewHolder> {
    public static final String TAG = BookmarkAdapter.class.getSimpleName();

    private int mPageCount = 0;
    private File mFile;
    private PdfRenderer mRenderer;
    private List<Bookmark> mBookmarks;

    public BookmarkAdapter() {
    }

    public void setBookmarks(List<Bookmark> bookmarks) {
        if (bookmarks.size() > 0) {
            if (mFile == null) {
                mFile = new File(bookmarks.get(0).getDocumentLocation());
            }
        }

        int startSize = mPageCount;
        //int endValue = startSize + list.size();

        mPageCount = bookmarks.size();
        if (bookmarks.size() <= startSize)
            notifyDataSetChanged();
        else {
            notifyItemRangeInserted(startSize, bookmarks.size());
        }

        mBookmarks = bookmarks;

        try {
            if (mFile != null) {
                mRenderer = new PdfRenderer(ParcelFileDescriptor.open(mFile, ParcelFileDescriptor.MODE_READ_ONLY));
            }
        } catch (IOException e) {
            Log.w(TAG, e);
        }
    }

    @NonNull
    @Override
    public BookmarkViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
        return new BookmarkViewHolder(parent);
    }

    @Override
    public void onBindViewHolder(@NonNull final BookmarkViewHolder holder, int position) {
        Bookmark currentBookmark = mBookmarks.get(position);

        holder.setPageNumber(currentBookmark.getBookmarkNumber() + 1);

        if (mFile.exists()) {
            PdfRenderer.Page page = mRenderer.openPage(position);
            float ratio = Math.max(
                    ScreenUtils.convertDpToPixel(100, holder.itemView.getContext()) / page.getWidth(),
                    ScreenUtils.convertDpToPixel(100, holder.itemView.getContext()) / page.getHeight());
            int width = Math.round(ratio * page.getWidth());
            int height = Math.round(ratio * page.getHeight());

            Bitmap b = Bitmap.createBitmap(width, height, Bitmap.Config.ARGB_4444);
            b.eraseColor(Color.WHITE);
            page.render(b, null, null, PdfRenderer.Page.RENDER_MODE_FOR_DISPLAY);
            page.close();

            holder.setThumbnailImage(b);
        }
    }

    @Override
    public int getItemCount() {
        return mPageCount;
    }
}