/*
 * RealWear Development Software, Source Code and Object Code.
 * (c) RealWear, Inc. All rights reserved.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Contact info@realwear.com for further information about the use of this code.
 */

package com.realwear.documentviewer.adapters;

import static com.realwear.internal.utils.Functional.runIfParameterNotNull;

import android.content.res.ColorStateList;
import android.graphics.Bitmap;
import android.os.Handler;
import android.view.LayoutInflater;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.constraintlayout.widget.ConstraintLayout;
import androidx.recyclerview.widget.RecyclerView;

import com.realwear.documentviewer.DocumentApplication;
import com.realwear.documentviewer.R;
import com.realwear.view.styles.ContainerStyle;
import com.realwear.view.styles.Theme;
import com.realwear.view.styles.ThemeAwareObject;
import com.realwear.view.styles.ThemeRegistrar;

public class BookmarkViewHolder extends RecyclerView.ViewHolder implements ThemeAwareObject {
    // each data item is just a string in this case
    private final TextView mPageText;
    private final ImageView mThumbnailImage;

    BookmarkViewHolder(@NonNull ViewGroup parent) {
        super(LayoutInflater.from(parent.getContext()).inflate(R.layout.bookmark, parent, false));
        mPageText = itemView.findViewById(R.id.title);
        mThumbnailImage = itemView.findViewById(R.id.image);
        ConstraintLayout container = itemView.findViewById(R.id.rounded_container);
        container.setClipToOutline(true);
        new Handler().post(() -> runIfParameterNotNull(t -> t.ensureObjectRegistered(this), ThemeRegistrar.getInstance()));
    }

    void setPageNumber(int number) {
        mPageText.setText(itemView.getContext().getString(R.string.select_page, number));
        mPageText.setOnClickListener(v -> DocumentApplication.getContext().gotoPage(number - 1));
        itemView.setOnClickListener(v -> DocumentApplication.getContext().gotoPage(number - 1));
    }

    void setThumbnailImage(Bitmap newImage) {
        mThumbnailImage.setImageBitmap(newImage);
    }

    @Override
    public void handleThemeUpdate(Theme theme) {
        final ContainerStyle style = theme.getContainerStyle(Theme.ContainerType.CONTAINED_BUTTON);
        style.getTextStyle().applyToTextView(mPageText);
        mPageText.setBackgroundTintList(ColorStateList.valueOf(style.getContainerColor()));
    }
}
