/*
 * RealWear Development Software, Source Code and Object Code.
 * (c) RealWear, Inc. All rights reserved.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Contact info@realwear.com for further information about the use of this code.
 */

package com.realwear.documentviewer.adapters;

import android.graphics.Bitmap;
import android.graphics.Color;
import android.graphics.pdf.PdfRenderer;
import android.os.ParcelFileDescriptor;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.RecyclerView;

import com.realwear.documentviewer.DocumentApplication;
import com.realwear.documentviewer.R;
import com.realwear.documentviewer.utils.ScreenUtils;

import java.io.File;
import java.io.IOException;

public class DocumentPreviewAdapter extends RecyclerView.Adapter<DocumentPreviewAdapter.ViewHolder> {
    private int mPageCount = 0;
    private String mLocation;
    private File mFile;
    private PdfRenderer mRedender;

    // Provide a reference to the views for each data item
    // Complex data items may need more than one view per item, and
    // you provide access to all the views for a data item in a view holder
    public class ViewHolder extends RecyclerView.ViewHolder {
        // each data item is just a string in this case
        TextView FileName;
        ImageView Image;
        public View View;

        ViewHolder(View v) {
            super(v);
            View = v;
            FileName = v.findViewById(R.id.title);
            Image = v.findViewById(R.id.image);
        }
    }

    public DocumentPreviewAdapter() {
    }

    public void setPageCount(int pageCount, String location) {
        if (mFile == null) {
            mFile = new File(location);
        }

        int startSize = mPageCount;
        //int endValue = startSize + list.size();

        mPageCount = pageCount;
        if (pageCount <= startSize)
            notifyDataSetChanged();
        else {
            notifyItemRangeInserted(startSize, pageCount);
        }

        mLocation = location;

        try {
            mRedender = new PdfRenderer(ParcelFileDescriptor.open(mFile, ParcelFileDescriptor.MODE_READ_ONLY));
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    @NonNull
    @Override
    public ViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
        View v = LayoutInflater.from(parent.getContext()).inflate(R.layout.preview_doc_small, parent, false);

        return new ViewHolder(v);
    }

    @Override
    public void onBindViewHolder(@NonNull final ViewHolder holder, final int position) {
        holder.FileName.setText(String.valueOf(position + 1));
        holder.View.setTag(position);
        holder.View.setOnClickListener(v -> {
            DocumentApplication.getContext().gotoPage(position);
            mRedender.close();
        });

        if (mFile.exists()) {
            PdfRenderer.Page page = mRedender.openPage(position);
            float ratio = Math.max(
                    ScreenUtils.convertDpToPixel(100, holder.FileName.getContext()) / page.getWidth(),
                    ScreenUtils.convertDpToPixel(100, holder.FileName.getContext()) / page.getHeight());
            int width = Math.round(ratio * page.getWidth());
            int height = Math.round(ratio * page.getHeight());

            Bitmap b = Bitmap.createBitmap(width, height, Bitmap.Config.ARGB_4444);
            b.eraseColor(Color.WHITE);
            page.render(b, null, null, PdfRenderer.Page.RENDER_MODE_FOR_DISPLAY);
            page.close();

            holder.Image.setImageBitmap(b);
        }
    }

    @Override
    public int getItemCount() {
        return mPageCount;
    }
}