/*
 * RealWear Development Software, Source Code and Object Code.
 * (c) RealWear, Inc. All rights reserved.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Contact info@realwear.com for further information about the use of this code.
 */

package com.realwear.documentviewer.fragment;

import android.net.Uri;

import com.realwear.documentviewer.object.Bookmark;

import java.util.List;

public interface IFragmentController {
    /**
     * Show the bookmark fragment.
     */
    void showBookmarkFragment();

    /**
     * Show the search fragment.
     */
    void showSearchFragment();

    /**
     * Attempt to bring up the tag management activity.
     */
    void manageTags();

    /**
     * Load the next file.
     */
    void nextFile();

    /**
     * Load the previous file.
     */
    void previousFile();

    /**
     * Delete the current file.
     */
    void deleteFile();

    /**
     * Returns whether the tag management interface should be available or not.
     *
     * @return True if so.
     */
    boolean allowsManageTags();

    /**
     * Returns whether the previous file option should be shown.
     *
     * @return True if so.
     */
    boolean allowsPreviousFile();

    /**
     * Returns whether the next file option should be shown.
     *
     * @return True if so.
     */
    boolean allowsNextFile();

    /**
     * Returns whether the delete file option should be shown.
     *
     * @return True if so.
     */
    boolean allowsDeleteFile();

    /**
     * Returns whether the bookmarks can be stored.
     *
     * @return True if so.
     */
    boolean canStoreBookmarks();

    /**
     * Get all stored bookmarks.
     *
     * @return The list of bookmarks for the current document.
     */
    List<Bookmark> getAllBookmarks();

    /**
     * Bookmark the current page.
     */
    void addBookmark(int pageNumber);

    /**
     * Unbookmark the current page.
     *
     * @param pageNumber
     */
    void deleteBookmark(int pageNumber);

    /**
     * Gets if a file path supports file tagging.
     *
     * @param filePath The file path to check.
     * @return True if the file path supports file tagging, otherwise false.
     */
    boolean fileSupportsTags(Uri filePath);
}
