/*
 * RealWear Development Software, Source Code and Object Code.
 * (c) RealWear, Inc. All rights reserved.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Contact info@realwear.com for further information about the use of this code.
 */

package com.realwear.documentviewer.fragment;

import android.app.Fragment;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;

import androidx.annotation.Nullable;
import androidx.recyclerview.widget.GridLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.realwear.documentviewer.R;
import com.realwear.documentviewer.adapters.DocumentPreviewAdapter;

public class ThumbNailViewerFragment extends Fragment implements View.OnClickListener {

    private RecyclerView mDocumentPreviewPages;
    private GridLayoutManager mLayoutManager;
    DocumentPreviewAdapter mAdapter;
    private Button mZoomIn, mZoomOut;

    public static ThumbNailViewerFragment newInstance() {
        return new ThumbNailViewerFragment();
    }

    @Nullable
    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {
        return inflater.inflate(R.layout.fragment_thumbnail, container, false);
    }

    @Override
    public void onViewCreated(View view, @Nullable Bundle savedInstanceState) {
        super.onViewCreated(view, savedInstanceState);

        mDocumentPreviewPages = view.findViewById(R.id.documentPreview);
        // in content do not change the layout size of the RecyclerView
        mDocumentPreviewPages.setHasFixedSize(false);

        mZoomIn = view.findViewById(R.id.zoom_in);
        mZoomOut = view.findViewById(R.id.zoom_out);
        mZoomIn.setOnClickListener(this);
        mZoomOut.setOnClickListener(this);
        mLayoutManager = new GridLayoutManager(getActivity(), 2);

        mLayoutManager.setOrientation(GridLayoutManager.HORIZONTAL);
        mAdapter = new DocumentPreviewAdapter();
        mDocumentPreviewPages.setLayoutManager(mLayoutManager);
        mDocumentPreviewPages.setAdapter(mAdapter);
    }

    public void setPageCount(int pageCount, String location) {
        mAdapter.setPageCount(pageCount, location);
    }

    public void scrollOut() {
        mLayoutManager.setSpanCount(mLayoutManager.getSpanCount() + 1);
        mDocumentPreviewPages.setLayoutManager(mLayoutManager);
        mAdapter.notifyDataSetChanged();
    }

    public void scrollIn() {
        mLayoutManager.setSpanCount(mLayoutManager.getSpanCount() - 1);
        mDocumentPreviewPages.setLayoutManager(mLayoutManager);
        mAdapter.notifyDataSetChanged();
    }

    @Override
    public void onClick(View view) {
        if (view.equals(mZoomOut)) {
            scrollOut();
        } else if (view.equals(mZoomIn)) {
            scrollIn();
        }
    }
}
