/*
 * RealWear Development Software, Source Code and Object Code.
 * (c) RealWear, Inc. All rights reserved.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Contact info@realwear.com for further information about the use of this code.
 */

package com.realwear.documentviewer.memory;

import static com.realwear.internal.utils.Utils.concatenateNonEmptyStrings;

import android.content.ContentResolver;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.net.Uri;

import com.squareup.picasso.Picasso;
import com.squareup.picasso.Request;
import com.squareup.picasso.RequestHandler;

import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;

public class BitmapRequestHandler extends RequestHandler {
    public static String SCHEME_BITMAP = "bitmap";
    private final ContentResolver mResolver;

    public BitmapRequestHandler(final ContentResolver resolver) {
        mResolver = resolver;
    }

    @Override
    public boolean canHandleRequest(Request data) {
        String scheme = data.uri.getScheme();
        return (SCHEME_BITMAP.equals(scheme));
    }

    @Override
    public Result load(Request data, int arg1) {
        final String rawUri = data.uri.toString();
        if (rawUri.contains("content://")) {
            return loadContentProvided(rawUri);
        } else {
            Bitmap bm = BitmapFactory.decodeFile(data.uri.getPath());
            return new Result(bm, Picasso.LoadedFrom.DISK);
        }
    }

    private Result loadContentProvided(String rawUri) {
        final String[] uriParts = rawUri.split(":");
        final String uriText = concatenateNonEmptyStrings(":", uriParts[1], uriParts[2]);
        try (InputStream input = mResolver.openInputStream(Uri.parse(uriText))) {
            return new Result(BitmapFactory.decodeStream(input), Picasso.LoadedFrom.DISK);
        } catch (FileNotFoundException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        }
        return null;
    }
}