/*
 * RealWear Development Software, Source Code and Object Code.
 * (c) RealWear, Inc. All rights reserved.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Contact info@realwear.com for further information about the use of this code.
 */

package com.realwear.documentviewer.utils;

import android.os.ParcelFileDescriptor;

import com.tom_roush.pdfbox.pdmodel.PDDocument;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;

/**
 * Util class containing helper methods for working with PDF files.
 */
public class PdfUtils {
    /**
     * Constructor.
     * Note this is a utility class so cannot be instantiated.
     */
    private PdfUtils() {
        throw new IllegalStateException("Utility class");
    }

    /**
     * Check if the PDF is password protected.
     *
     * @param location The path of the PDF file.
     * @return true if the PDF file requires a password to be loaded, false if not.
     */
    public static boolean isPdfOpenEncrypted(String location) {
        try (PDDocument ignored = PDDocument.load(new File(location))) {
            return false;
        } catch (IOException e) {
            return true;
        }
    }

    /**
     * Check if the PDF is password protected.
     *
     * @param descriptor The raw file descriptor used to access the PDF data.
     * @return true if the PDF file requires a password to be loaded, false if not.
     */
    public static boolean isPdfOpenEncrypted(ParcelFileDescriptor descriptor) {
        try (FileInputStream input = new FileInputStream(descriptor.getFileDescriptor());
             PDDocument ignored = PDDocument.load(input)) {
            return false;
        } catch (IOException e) {
            return true;
        }
    }
}
